@@ -5,7 +5,7 @@ author = {
 	"email":"maloja@krateng.dev",
 	"github": "krateng"
 }
-version = 2,3,4
+version = 2,4,1
 versionstr = ".".join(str(n) for n in version)
 links = {
 	"pypi":"malojaserver",
@@ -19,9 +19,11 @@ requires = [
 	"nimrodel>=0.6.3",
 	"setproctitle>=1.1.10",
 	"wand>=0.5.4",
-	"lesscpy>=0.13"
+	"lesscpy>=0.13",
+	"jinja2>2.11"
 ]
 resources = [
+	"web/*/*/*",
 	"web/*/*",
 	"web/*",
 	"static/*/*",
